Advent of Code helpers
======================
.. image:: https://travis-ci.org/mvaal/advent-of-code-helpers.svg?branch=master
    :target: https://travis-ci.org/mvaal/advent-of-code-helpers
.. image:: https://badge.fury.io/py/advent-of-code-helpers.svg
    :target: https://badge.fury.io/py/advent-of-code-helpers
.. image:: https://coveralls.io/repos/github/mvaal/advent-of-code-helpers/badge.svg
    :target: https://coveralls.io/github/mvaal/advent-of-code-helpers

Advent of Code helper functions

.. code-block:: python

   from aoc.helpers import output, read_input_from_file, input_lines

Setup Guide
-----------

Install with pip

.. code-block:: bash

   pip install advent-of-code-helpers